/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.games.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * This is a JSON template for a ListScores response.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Play Game Services API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class LeaderboardScores extends GenericJson {

  /**
   * The scores in the leaderboard.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<LeaderboardEntry> items;

  static {
    // hack to force ProGuard to consider LeaderboardEntry used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(LeaderboardEntry.class);
  }

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#leaderboardScores.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The pagination token for the next page of results.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String nextPageToken;

  /**
   * The total number of scores in the leaderboard.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long numScores;

  /**
   * The score of the requesting player on the leaderboard. The player's score may appear both here
   * and in the list of scores above. If you are viewing a public leaderboard and the player is not
   * sharing their gameplay information publicly, the scoreRank and formattedScoreRank values will
   * not be present.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private LeaderboardEntry playerScore;

  /**
   * The pagination token for the previous page of results.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String prevPageToken;

  /**
   * The scores in the leaderboard.
   * The value returned may be {@code null}.
   */
  public java.util.List<LeaderboardEntry> getItems() {
    return items;
  }

  /**
   * The scores in the leaderboard.
   * The value set may be {@code null}.
   */
  public LeaderboardScores setItems(java.util.List<LeaderboardEntry> items) {
    this.items = items;
    return this;
  }

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#leaderboardScores.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#leaderboardScores.
   * The value set may be {@code null}.
   */
  public LeaderboardScores setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The pagination token for the next page of results.
   * The value returned may be {@code null}.
   */
  public String getNextPageToken() {
    return nextPageToken;
  }

  /**
   * The pagination token for the next page of results.
   * The value set may be {@code null}.
   */
  public LeaderboardScores setNextPageToken(String nextPageToken) {
    this.nextPageToken = nextPageToken;
    return this;
  }

  /**
   * The total number of scores in the leaderboard.
   * The value returned may be {@code null}.
   */
  public Long getNumScores() {
    return numScores;
  }

  /**
   * The total number of scores in the leaderboard.
   * The value set may be {@code null}.
   */
  public LeaderboardScores setNumScores(Long numScores) {
    this.numScores = numScores;
    return this;
  }

  /**
   * The score of the requesting player on the leaderboard. The player's score may appear both here
   * and in the list of scores above. If you are viewing a public leaderboard and the player is not
   * sharing their gameplay information publicly, the scoreRank and formattedScoreRank values will
   * not be present.
   * The value returned may be {@code null}.
   */
  public LeaderboardEntry getPlayerScore() {
    return playerScore;
  }

  /**
   * The score of the requesting player on the leaderboard. The player's score may appear both here
   * and in the list of scores above. If you are viewing a public leaderboard and the player is not
   * sharing their gameplay information publicly, the scoreRank and formattedScoreRank values will
   * not be present.
   * The value set may be {@code null}.
   */
  public LeaderboardScores setPlayerScore(LeaderboardEntry playerScore) {
    this.playerScore = playerScore;
    return this;
  }

  /**
   * The pagination token for the previous page of results.
   * The value returned may be {@code null}.
   */
  public String getPrevPageToken() {
    return prevPageToken;
  }

  /**
   * The pagination token for the previous page of results.
   * The value set may be {@code null}.
   */
  public LeaderboardScores setPrevPageToken(String prevPageToken) {
    this.prevPageToken = prevPageToken;
    return this;
  }

}
