/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.games.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * This is a JSON template for a player leaderboard score object.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Play Game Services API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class PlayerLeaderboardScore extends GenericJson {

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#playerLeaderboardScore.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The ID of the leaderboard this score is in.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("leaderboard_id")
  private String leaderboardId;

  /**
   * The public rank of the score in this leaderboard. This object will not be present if the user
   * is not sharing their scores publicly.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private LeaderboardScoreRank publicRank;

  /**
   * The formatted value of this score.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String scoreString;

  /**
   * The numerical value of this score.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long scoreValue;

  /**
   * The social rank of the score in this leaderboard.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private LeaderboardScoreRank socialRank;

  /**
   * The time span of this score. Possible values are:   - "ALL_TIME" - The score is an all-time
   * score.  - "WEEKLY" - The score is a weekly score.  - "DAILY" - The score is a daily score.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String timeSpan;

  /**
   * The timestamp at which this score was recorded, in milliseconds since the epoch in UTC.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long writeTimestamp;

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#playerLeaderboardScore.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#playerLeaderboardScore.
   * The value set may be {@code null}.
   */
  public PlayerLeaderboardScore setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The ID of the leaderboard this score is in.
   * The value returned may be {@code null}.
   */
  public String getLeaderboardId() {
    return leaderboardId;
  }

  /**
   * The ID of the leaderboard this score is in.
   * The value set may be {@code null}.
   */
  public PlayerLeaderboardScore setLeaderboardId(String leaderboardId) {
    this.leaderboardId = leaderboardId;
    return this;
  }

  /**
   * The public rank of the score in this leaderboard. This object will not be present if the user
   * is not sharing their scores publicly.
   * The value returned may be {@code null}.
   */
  public LeaderboardScoreRank getPublicRank() {
    return publicRank;
  }

  /**
   * The public rank of the score in this leaderboard. This object will not be present if the user
   * is not sharing their scores publicly.
   * The value set may be {@code null}.
   */
  public PlayerLeaderboardScore setPublicRank(LeaderboardScoreRank publicRank) {
    this.publicRank = publicRank;
    return this;
  }

  /**
   * The formatted value of this score.
   * The value returned may be {@code null}.
   */
  public String getScoreString() {
    return scoreString;
  }

  /**
   * The formatted value of this score.
   * The value set may be {@code null}.
   */
  public PlayerLeaderboardScore setScoreString(String scoreString) {
    this.scoreString = scoreString;
    return this;
  }

  /**
   * The numerical value of this score.
   * The value returned may be {@code null}.
   */
  public Long getScoreValue() {
    return scoreValue;
  }

  /**
   * The numerical value of this score.
   * The value set may be {@code null}.
   */
  public PlayerLeaderboardScore setScoreValue(Long scoreValue) {
    this.scoreValue = scoreValue;
    return this;
  }

  /**
   * The social rank of the score in this leaderboard.
   * The value returned may be {@code null}.
   */
  public LeaderboardScoreRank getSocialRank() {
    return socialRank;
  }

  /**
   * The social rank of the score in this leaderboard.
   * The value set may be {@code null}.
   */
  public PlayerLeaderboardScore setSocialRank(LeaderboardScoreRank socialRank) {
    this.socialRank = socialRank;
    return this;
  }

  /**
   * The time span of this score. Possible values are:   - "ALL_TIME" - The score is an all-time
   * score.  - "WEEKLY" - The score is a weekly score.  - "DAILY" - The score is a daily score.
   * The value returned may be {@code null}.
   */
  public String getTimeSpan() {
    return timeSpan;
  }

  /**
   * The time span of this score. Possible values are:   - "ALL_TIME" - The score is an all-time
   * score.  - "WEEKLY" - The score is a weekly score.  - "DAILY" - The score is a daily score.
   * The value set may be {@code null}.
   */
  public PlayerLeaderboardScore setTimeSpan(String timeSpan) {
    this.timeSpan = timeSpan;
    return this;
  }

  /**
   * The timestamp at which this score was recorded, in milliseconds since the epoch in UTC.
   * The value returned may be {@code null}.
   */
  public Long getWriteTimestamp() {
    return writeTimestamp;
  }

  /**
   * The timestamp at which this score was recorded, in milliseconds since the epoch in UTC.
   * The value set may be {@code null}.
   */
  public PlayerLeaderboardScore setWriteTimestamp(Long writeTimestamp) {
    this.writeTimestamp = writeTimestamp;
    return this;
  }

}
